@@ -1,19 +1,21 @@
 import os.path as op
+
 from datalad.api import Dataset
-from datalad.tests.utils import (
-    ok_clean_git,
+from datalad.tests.utils_pytest import (
     assert_in,
-    assert_is_instance,
     assert_in_results,
+    assert_is_instance,
+    assert_raises,
     assert_result_count,
-    assert_raises
+    ok_clean_git,
+    with_tree,
 )
-from datalad.tests.utils import with_tree
+
 from datalad_container.find_container import find_container
 
 
 @with_tree(tree={"sub": {"i.img": "doesn't matter"}})
-def test_find_containers(path):
+def test_find_containers(path=None):
     ds = Dataset(path).create(force=True)
     ds.save(path=[op.join('sub', 'i.img')], message="dummy container")
     ds.containers_add("i", image=op.join('sub', 'i.img'))
